@@ -1,11 +1,12 @@
 package UNIVERSAL::can;
-BEGIN {
-  $UNIVERSAL::can::VERSION = '1.20110613';
+{
+  $UNIVERSAL::can::VERSION = '1.20120726';
 }
 # ABSTRACT: work around buggy code calling UNIVERSAL::can() as a function
 
 use strict;
 use warnings;
+use 5.008;
 
 use vars qw( $recursing $always_warn );
 
@@ -149,7 +150,7 @@ this module needed to do what it does now.
 
 =head1 COPYRIGHT & LICENSE
 
-Artistic License 2.0, copyright (c) 2005 - 2011 chromatic. Some rights
-reserved.
+Copyright (c) 2005 - 2011, chromatic. This module is made available under the
+same terms as Perl 5.12.
 
 =cut
